@@ -64,10 +64,11 @@ def cli_main():
     parser.add_argument('--out_pre', default="", help='Output files prefix')
     parser.add_argument('--out_dir', default="output", help='Output directory')
     parser.add_argument('--db_dir', default="db", help='Database directory')
-    parser.add_argument('--cgc_dis', default=2, help='CGCFinder Distance value')
+    parser.add_argument('--cgc_dis', default=2, type=int, help='CGCFinder Distance value')
     parser.add_argument('--cgc_sig_genes', default='tp', choices=['tp', 'tf','all'], help='CGCFinder Signature Genes value')
     parser.add_argument('--tools', '-t', nargs='+', choices=['hmmer', 'diamond', 'eCAMI', 'all'], default='all', help='Choose a combination of tools to run')
     parser.add_argument('--use_signalP', default=False, type=bool, help='Use signalP or not, remember, you need to setup signalP tool first. Because of signalP license, Docker version does not have signalP.')
+    parser.add_argument('--signalP_path', '-sp',default="signalp", type=str, help='The path for signalp. Default location is signalp')
     parser.add_argument('--gram', '-g', choices=["p","n","all"], default="all", help="Choose gram+(p) or gram-(n) for proteome/prokaryote nucleotide, which are params of SingalP, only if user use singalP")
     args = parser.parse_args()
 
@@ -154,9 +155,9 @@ def cli_main():
     if args.use_signalP:
         print("\n\n***************************0. SIGNALP start*************************************************\n\n")
         if args.gram == "p" or args.gram=="all":
-            signalpos = Popen('signalp -t gram+ %suniInput > %ssignalp.pos' % (outPath, outPath), shell=True)
+            signalpos = Popen('%s -t gram+ %suniInput > %ssignalp.pos' % (args.signalP_path, outPath, outPath), shell=True)
         if args.gram == "n" or args.gram == "all":
-            signalpneg = Popen('signalp -t gram- %suniInput > %ssignalp.neg' % (outPath, outPath), shell=True)
+            signalpneg = Popen('%s -t gram- %suniInput > %ssignalp.neg' % (args.signalP_path, outPath, outPath), shell=True)
 
     # End SignalP
     #######################
@@ -194,7 +195,6 @@ def cli_main():
     if tools[2]:
         print("\n\n***************************3. eCAMI start***************************************************\n\n")
         print("Using "+args.eCAMI_kmer_db+" db in eCAMI")
-        # exit(0)
         ecami_config = eCAMI_config(
             db_type = args.eCAMI_kmer_db,
             input = f"{outPath}uniInput",
@@ -224,12 +224,17 @@ def cli_main():
         call(['mv', outPath+'temp', outPath+'eCAMI.out'])
 
     if tools[1]:
-        with open(outDir+prefix+'hmmer.out') as f:
+        try:
+            with open(outDir+prefix+'hmmer.out') as f:
+                with open(outDir+prefix+'temp', 'w') as out:
+                    out.write('HMM Profile\tProfile Length\tGene ID\tGene Length\tE Value\tProfile Start\tProfile End\tGene Start\tGene End\tCoverage\n')
+                    for line in f:
+                        out.write(line)
+            call(['mv', outDir+prefix+'temp', outDir+prefix+'hmmer.out'])
+        except:
             with open(outDir+prefix+'temp', 'w') as out:
-                out.write('HMM Profile\tProfile Length\tGene ID\tGene Length\tE Value\tProfile Start\tProfile End\tGene Start\tGene End\tCoverage\n')
-                for line in f:
-                    out.write(line)
-        call(['mv', outDir+prefix+'temp', outDir+prefix+'hmmer.out'])
+                    out.write('HMM Profile\tProfile Length\tGene ID\tGene Length\tE Value\tProfile Start\tProfile End\tGene Start\tGene End\tCoverage\n')
+            call(['mv', outDir+prefix+'temp', outDir+prefix+'hmmer.out'])
 
     if tools[0]:
         with open(outDir+prefix+'diamond.out') as f:
@@ -410,9 +415,11 @@ def cli_main():
                                     for x in note:
                                         temp = x.split('=')
                                         notes[temp[0]] = temp[1]
-                                    if "Name" in notes:
-                                        gene = notes["Name"]
-                                    elif "ID" in notes:
+#                                     if "Name" in notes:
+#                                         gene = notes["Name"]
+#                                     elif "ID" in notes:
+#                                         gene = notes["ID"]
+                                    if "ID" in notes:
                                         gene = notes["ID"]
                                     else:
                                         continue
@@ -513,6 +520,9 @@ def cli_main():
     def unique(seq):
         exists = set()
         return [x for x in seq if not (x in exists or exists.add(x))]
+    
+    arr_eCAMI = None
+    arr_hmmer = None
 
     # check if files exist. if so, read files and get the gene numbers
     if tools[0]:
